<?php
/**
 * Plugin Qcm (addon for plugin Adm_redacteurs)
 * Version  : 1.3 (2018/04/12)
 * Compatibility : Guppy v5.0+ et Adm_redacteurs v6.12+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_HELPERS_PATH.'/add_record_helper.php';

class Add_qcm_results_helper extends Add_record_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI;                       // object global
    protected $_lang = array();          // Données de langue
    protected $_config = array();        // Données de configuration  
    protected $_record_id = 0;           // Identifiant de l'enregistrement
    protected $_record_data = array();   // Tableau contenant les données de l'enregistrement
    protected $_form_params = array();   // Tableau contenant les données de l'enregistrement postées dans le formulaire
 	protected $_form_errors = array();	 // Tableau contenant les messages d'erreur dans le formulaire
    protected $_form_validation = FALSE; // Validation du formulaire (TRUE ou FALSE)

    protected $_doc_infos = array('type' => 'qcm_results', 'name' => 'qcm'); // Infos concernant le document (type, name)
    protected $_writer_rights = array(); // Droits du rédacteur
    
    protected $_qcm_questions_data = array(); // Tableau contenant les données des questions des qcm
    protected $_qcm_results = array(); // Tableau contenant les résultats pour chaque réponse obtenus lors de la soumission du formulaire
    
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    public function __construct()
    {
        $this -> CI =& Controller :: get_instance();

        $this -> CI -> load_helper('date_helper');
        $this -> CI -> load_helper('private_groups_helper');

        $this -> CI -> load_addon_helper('qcm', 'qcm_infos_helper');
       
        $this -> CI -> load_addon_model('qcm', 'qcm_ids_model');
        $this -> CI -> load_addon_model('qcm', 'qcm_params_model');
        
        $this -> CI -> load_addon_lang('qcm');
        $this -> CI -> load_addon_config('qcm');
        
        $this -> CI -> load_library('php_session');
        
        $this -> _lang = $this -> CI -> get_lang();
        $this -> _config = $this -> CI -> get_config();        

        parent :: __construct();

        $this -> _qcm_questions_data = $this -> _get_qcm_questions_data();
        $this -> _qcm_results = $this -> _get_qcm_results();
               
        /**
         * Controle de sécurité nécessaire si ce n'est pas l'admin qui est aux commandes
         */
 /*       if (!ADMR_IS_ADMIN && !$this -> _is_doc_allowed()) {
            Url_helper :: redirect('display_error&type=page_not_allowed');
        }*/
        //

        if (! $this -> _form_validation) { // Formulaire non validé
            $this -> CI -> php_session -> keep_flashdata('all_qcm_questions_display_order'); // Conservation de l'ordre d'affichage des questions
        } else {
           $this -> CI -> php_session -> clear('all_qcm_questions_display_order'); 
        }

    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */    

    /**
	 * Index
     * 
	 * @access public
     * @return void
	 */	
    public function index()
    {
        parent :: index();
    }

	// --------------------------------------------------------------------

    /*
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
    public function set_title_page()
    {
        return !empty($this -> _record_data['id']) ? $this -> _record_data['title'] : $this -> _lang['errors_msg']['error_404'];        
    }

	// --------------------------------------------------------------------

    /**
     * Définit et renvoie le mode d'affichage des boites latérales selon le choix sélectionné dans le document
     *
     * @return string
     */
    public function set_sidebars_display_mode()
    {
        return $this -> _record_data['sidebars'];
    }

	// --------------------------------------------------------------------

    /**
     * Définit et renvoie le chemin de l'icone du document
     *
     * @return string Chemin relatif de l'icone
     */
    public function set_icon_page()
    {
        return $this -> _record_data['icon'];
    }

	// --------------------------------------------------------------------

	/**
	 * définit et renvoie les ajouts (js et css) dans l'entête de la page
     * 
     * @access public
	 * @return string Chaine html contenant les ajouts js et css
	 */	
    public function set_header_addons()
    {
        $js = '';
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/placeholder/jquery.placeholder.min.js"></script>'."\n";
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/datetimepicker/jquery.datetimepicker.min.js"></script>'."\n";
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/form-validator/jquery.form-validator.min.js"></script>'."\n";
        $js .= '<script type="text/javascript">$.formUtils.loadModules("module_add_doc", "'.ADMR_JS_PATH.'/form-validator/my_modules/");</script>'."\n";
        $js .= '<script type="text/javascript" src="'.ADMR_JS_PATH.'/add_doc.js"></script>'."\n";
       
        $css = '';
        $css .= '<link rel="stylesheet" type="text/css" href="'.ADMR_CSS_PATH.'/form_validator.css" />'."\n";
        $css .= '<link rel="stylesheet" type="text/css" href="'.ADMR_CSS_PATH.'/add_doc.css" />'."\n";

        return $css.$js;
    }

	// --------------------------------------------------------------------

	/**
	 * construit et retourne le contenu de l'attribut action du formulaire
     * 
     * @access protected
     * @param mixed Options du menu select
	 * @return void
	 */	
    protected function _build_form_action_content()
    {
        return $this -> _get_current_url();
    }

	// --------------------------------------------------------------------

    /**
	 * Ajoute des données supplémentaires pour la vue sous la forme array(key => value)
     * 
	 * @access protected
     * @return array
	 */	
    protected function _add_more_data_for_add_record_view()
    {
        return array(
            'is_allowed_for_publication' => $this -> _is_allowed_for_publication(),

            'qcm_questions_data' => $this -> _qcm_questions_data,
            'qcm_questions_display_order' => $this -> _get_qcm_questions_display_order(),
            'qcm_results' => $this -> _qcm_results,
            'count_qcm_results' => $this -> _count_qcm_results(),        
            
            'author' => $this -> _get_author(),
            'nb_views' => $this -> _get_nb_views(),
            'lang_index' => ($this -> _config['lang'][1] === ADMR_LNG) ? 2 : 1,
        );    
    }

	// --------------------------------------------------------------------

    /**
     * Vérifie si le document est autorisé à être publié 
     *
     * @return boolean
     */
    protected function _is_allowed_for_publication()
    {
        if (!empty($this -> _record_data) && $this -> _record_data['status'] == 'a'
            && Date_helper :: is_valid_date_for_publication($this -> _record_data['createdate'])
            && Private_groups_helper :: is_allowed_for_access($this -> _record_data['group']))
        {
            return TRUE;    
        }           
        
        return FALSE;
    }
    
	// --------------------------------------------------------------------

    /**
     * Renvoie l'ordre d'affichage des questions du qcm
     *
     * @return array
     */
    protected function _get_qcm_questions_display_order()
    {
        $all_qcm_questions_display_order = array($this -> _record_data['id'] => array());
        $all_qcm_questions_display_order = $this -> CI -> php_session -> get_flashdata('all_qcm_questions_display_order');

        if (empty($all_qcm_questions_display_order[$this -> _record_data['id']])) {
            $this -> CI -> load_addon_model('qcm', 'qcm_questions_ids_model', array('qcm_id' => $this -> _record_data['id']));
            $qcm_questions = $this -> CI -> qcm_questions_ids_model -> get(array('status' => 'a'), 'order_asc');        
                
            foreach($qcm_questions as $qcm_question) {
                $all_qcm_questions_display_order[$this -> _record_data['id']][] = $qcm_question['id'];    
            }
                  
            // Affichage aléatoire des questions
            if (!empty($this -> _record_data['display_questions_randomly'])) {
                shuffle($all_qcm_questions_display_order[$this -> _record_data['id']]);    
            }
           
            $this -> CI -> php_session -> save_flashdata('all_qcm_questions_display_order', $all_qcm_questions_display_order);    
        }       

        return $all_qcm_questions_display_order[$this -> _record_data['id']];
    }
    
	// --------------------------------------------------------------------

    /**
     * Renvoie les résultats des réponses des questions soumises lors de la validation du formulaire
     *
     * @return boolean
     */
    protected function _get_qcm_results()
    {
        $qcm_results = array();
      
        if ($this -> _form_validation) {
            $this -> CI -> load_addon_model('qcm', 'qcm_questions_ids_model', array('qcm_id' => $this -> _record_data['id']));
            $questions = $this -> CI -> qcm_questions_ids_model -> get(array('status' => 'a'));        
            $answers = $this -> _form_params['answers'];
            
            foreach ($questions as $question) {               
                $question_id = $question['id'];
              
                if (isset($answers[$question_id])) {                   
                    $true_answers = explode(',', (string) $question['answers_ids']);
                    
                    if (is_array($answers[$question_id])) {
                        foreach($answers[$question_id] as $answer_key) {                       
                            $qcm_results[$question_id][$answer_key] = in_array($answers[$question_id][$answer_key], $true_answers) ? 1 : 0;
                        }                        
                    } else {
                        $qcm_results[$question_id] = in_array($answers[$question_id], $true_answers) ? 1 : 0;                        
                    }
                }                    
            }            
        }

        return $qcm_results;
    }
/*
    protected function _get_qcm_results()
    {
        $qcm_results = array();
      
        if ($this -> _form_validation) {
            $this -> CI -> load_addon_model('qcm', 'qcm_questions_ids_model', array('qcm_id' => $this -> _record_data['id']));
            $questions = $this -> CI -> qcm_questions_ids_model -> get(array('status' => 'a'));        
            $answers = $this -> _form_params['answers'];
            
            foreach ($questions as $question) {               
                $question_id = $question['id'];
              
                if (isset($answers[$question_id]) && in_array($answers[$question_id], explode(',', (string) $question['answers_ids']))) {
                    $qcm_results[$question_id] = 1;   
                } else {
                    $qcm_results[$question_id] = 0;
                }                    
            }            
        }

        return $qcm_results;
    }
*/
	// --------------------------------------------------------------------

    /**
     * Renvoie le bilan des résultats obtenus
     *
     * @return boolean
     */
/*    protected function _count_qcm_results()
    {    
        settype($this -> _qcm_results, 'array');

        return array_count_values($this -> _qcm_results) + array(0, 0);
    }
*/
	// --------------------------------------------------------------------

    /**
     * Renvoie le bilan des résultats obtenus
     *
     * @return boolean
     */
    protected function _count_qcm_results()
    {    
        settype($this -> _qcm_results, 'array');
        
        $qcm_results = array();
        
        foreach($this -> _qcm_results as $results) {
            $qcm_results = array_merge($qcm_results, (array) $results);    
        }
        
        return array_count_values($qcm_results) + array(0, 0);
    }

	// --------------------------------------------------------------------

    /**
     * Renvoie les données des questions
     *
     * @return boolean
     */
    protected function _get_qcm_questions_data()
    {
        $questions_data = array();
        $this -> CI -> load_addon_model('qcm', 'qcm_questions_ids_model', array('qcm_id' => $this -> _record_data['id']));
        $this -> CI -> load_addon_model('qcm', 'qcm_questions_model');
        
        $questions = $this -> CI -> qcm_questions_ids_model -> get(array('status' => 'a'));            

        foreach($questions as $question)
        {
            $questions_data[$question['id']] = $this -> CI -> qcm_questions_model -> read($question['id']);
            $questions_data[$question['id']]['is_answers_multiple'] = strpos($question['answers_ids'], ',') ? TRUE : FALSE;                 
        }

        return $questions_data;
    }
    
	// --------------------------------------------------------------------

    /**
     * Renvoie le nom de l'auteur
     *
     * @return boolean
     */
    protected function _get_author()
    {
        $this -> CI -> load_model('writer_model');            
        
        $author = $this -> CI -> writer_model -> get_by_id($this -> _record_data['author_id']);
       
        return empty($author) ? $this -> _config['user'][0] : $author['name'];
    }

	// --------------------------------------------------------------------

    /**
     * Renvoie le nombre de vue de l'article
     *
     * @return boolean
     */
    protected function _get_nb_views()
    {
        $this -> CI -> load_addon_model('qcm', 'qcm_counters_model', $this -> _record_data['id']);            
        
        $this -> CI -> qcm_counters_model -> increase_counter();
       
        return $this -> CI -> qcm_counters_model -> get_counter();
    }

	// --------------------------------------------------------------------

    /**
	 * Définit et retourne le layout de la vue
     * 
	 * @access protected
     * @return string nom du fichier qui définit le layout
	 */	
    protected function _get_layout_for_add_record_view()
    {      
    /*    if ($this -> _record_data['display_questions_in_same_page']) {
            $view = str_replace(ADMR_PUBLIC_ROOT_PATH, '..', QCM_VIEWS_PATH).'/qcm';    
        } else  {
            $view = str_replace(ADMR_PUBLIC_ROOT_PATH, '..', QCM_VIEWS_PATH).'/qcm_2';    
        }
        
        return $view;*/
        
        return str_replace(ADMR_PUBLIC_ROOT_PATH, '..', QCM_VIEWS_PATH).'/qcm';
    }
    
	// --------------------------------------------------------------------

    /**
	 * Ajoute ou modifie un enregistrement
     * 
	 * @access protected
     * @return boolean
	 */	
    protected function _add_record()
    {
        return parent :: _add_record();
    }

	// --------------------------------------------------------------------

    /**
	 * Crée un nouvel enregistrement dans la base de donnée
     * 
	 * @access protected
     * @param array Tableau contenant les données de l'enregistrement
     * @return integer Identifiant de l'enregistrement créé
	 */
    protected function _insert_record($record)
    {
        return FALSE;
/*		$record['author_id'] = $this -> _get_writer_id();
        
        $record['id'] = $this -> CI -> qcm_ids_model -> insert($record);
        $this -> CI -> qcm_params_model -> write($record);
    
        return $record['id'];  */  
    }
    
	// --------------------------------------------------------------------

    /**
	 * Met à jours les données de l'enregistrement dans la base de donnée
     * 
	 * @access protected
     * @param array Tableau contenant les données de l'enregistrement
     * @return void
	 */
    protected function _update_record($record)
    {    
        return FALSE;    
    }
    
	// --------------------------------------------------------------------

    /**
	 * Ajoute d'autres actions après l'ajout ou la mise à jour d'un document
     * 
	 * @access protected
     * @return void
	 */
    protected function _add_more_action_after_adding_record()
    {
        $params =& $this -> _form_params;

        // Nothing        
    }

	// --------------------------------------------------------------------
    
    /**
	 * Définit et renvoie l'identifiant de l'enregistrement
     * 
	 * @access protected
     * @return array
	 */    
    protected function _set_record_id()
    {
        $this -> _record_id = Var_helper :: import('pg', 'POST_GET', 0, array('trim'), array(array('Var_helper', 'is_digit')));

        return $this -> _record_id;
    }

	// --------------------------------------------------------------------
    
    /**
	 * Définit les valeurs des paramètres du formulaire
     * 
	 * @access protected
     * @param integer Id de l'enregistrement
     * @return array
	 */    
    protected function _set_form_params()
    {
 //       return parent :: _set_form_params();
        $params = parent :: _set_form_params();
               
        $this -> CI -> load_addon_model('qcm', 'qcm_questions_ids_model', array('qcm_id' => $this -> _record_data['id']));
        $questions = $this -> CI -> qcm_questions_ids_model -> get(array('status' => 'a'));            
        
        foreach($questions as $question) {
            $params['answers_'.$question['id']] = isset($params['answers'][$question['id']]) ? $params['answers'][$question['id']] : '';
        }
     
        return $params;
    }

	// --------------------------------------------------------------------
    
    /**
	 * Récupère et renvoie les paramètres postés dans le formulaire
     * 
	 * @access protected
     * @return array Tableau contenant les paramètres postés dans le formulaire
	 */    
/*    protected function _get_form_params_posted()
    {
        $params = parent :: _get_form_params_posted();

        
        return $params; // Paramètres postés dans le formulaire       
    }
*/
	// --------------------------------------------------------------------
    
    /**
	 * Récupère et renvoie les données du document
     * 
	 * @access protected
     * @param integer Id de l'enregistrement
     * @return array Données enregistrées du document
	 */    
    protected function _get_record_data($record_id)
    {
        $this -> CI -> load_addon_model('qcm', 'qcm_params_model');
        $this -> CI -> load_addon_model('qcm', 'qcm_ids_model');

        $record_data = array_merge(
            $this -> CI -> qcm_params_model -> read($record_id),
            $this -> CI -> qcm_ids_model -> get_by_id($record_id)            
        );

        if (!empty($record_data)) {
            $lang_index = ($this -> _config['lang'][1] === ADMR_LNG) ? 2 : 1;     
    
            foreach(array('title', 'previous_page_label', 'previous_page_uri', 'next_page_label', 'next_page_uri') as $item) {
                $record_data[$item] = $record_data[$item.$lang_index];
            }
    
            foreach(array('contents_before', 'contents_after') as $item) {
                $record_data[$item] = Var_helper :: convert_relative_path_to_absolute($record_data[$item.$lang_index]);
            }
        }       
        
        return $record_data;
    }

	// --------------------------------------------------------------------

    /**
	 * définit et renvoie les règles de validation des paramètres du formulaire
     * 
	 * @access protected
     * @param array Tableau contenant les paramètres à vérifer lors de la validation
     * @return array Tableau contenant les règles de validation des paramètres ainsi que les messages d'erreur associés 
     * sous la forme suivante : array(param1 => array(
     *                                               array('rules' => '', 'msg' => ''), // error 1
     *                                               array('rules' => '', 'msg' => ''), // error 2                                       
     *                                         ),
     *                                param2 => array(
     *                                               array('rules' => '', 'msg' => ''), // error 1
     *                                               array('rules' => '', 'msg' => ''), // error 2                                       
     *                                         ),
     *                               ...
     *                          )
	 */	
    protected function _get_form_params_rules($params)
    {
        $params_rules = array();
        $this -> CI -> load_addon_model('qcm', 'qcm_questions_ids_model', array('qcm_id' => $this -> _record_data['id']));
        $questions = $this -> CI -> qcm_questions_ids_model -> get(array('status' => 'a'));            
        
        foreach($questions as $question) {
            $params_rules['answers_'.$question['id']] = array(           
                array(
                    'rules' => array(array('Var_helper', 'is_required')),
                    'msg' => ucfirst($this -> _lang['form_errors_msg']['please_check_an_answer'])
                ),
                array(
                    'rules' => array(array('Var_helper', 'is_digit')),
                    'msg' => ucfirst($this -> _lang['form_errors_msg']['value_is_not_integer'])
                )
            );         
        }
        
       return $params_rules;
    }

	// --------------------------------------------------------------------

	/**
	 * retourne l'url complète de la page
     * 
     * @access protected
	 * @return string Url complète de la page
	 */
    protected function _get_current_url()
    {
        return Url_helper :: build_uri(array(
                'pg'      => $this -> _record_id,
                'tconfig' => Var_helper :: import('tconfig', '', NULL, array('trim'), array(array('Var_helper', 'is_digit'))),
            ),
            ADMR_SITE_URL.QCM_PUBLIC_FILE_PATH.'?lng='.ADMR_LNG
        );
    }

	// --------------------------------------------------------------------

    /**
	 * Vérifie la validité d'accès au document
     * 
	 * @access public
     * @param integer Identifiant du document
     * @return void
	 */
/*    protected function _is_doc_allowed()
    {   
        if (!empty($this -> _record_data) && $this -> _record_data['status'] == 'a'
            && Date_helper :: is_valid_date_for_publication($this -> _record_data['createdate'])
            && Private_groups_helper :: is_allowed_for_access($this -> _record_data['group']))
        {
            return TRUE;    
        }           
        
        return FALSE;    
    }*/

	// --------------------------------------------------------------------

 } // End of class